@@ -46,4 +46,9 @@ class UnableToValidate(ScratchCloudException):
     Raised when an issue occurs with username validation.
     """
 
-    pass
\ No newline at end of file
+    pass
+
+class ScratchWebsocketError(ScratchCloudException):
+    """Scratch Websocket Error.
+    Raised when an issue connecting to the scratch websocket occurs.
+    """
\ No newline at end of file
