@@ -1,5 +1,4 @@
 from __future__ import annotations
-from typing import List, Union
 from datetime import datetime
 from enum import Enum
 from dataclasses import InitVar, dataclass
@@ -15,7 +14,7 @@ class APIConnection:
     def __init__(self, client: CloudClient):
         self.client: CloudClient = client
     
-    async def fetch_user(self, user: Union[str, 'User', 'IncompleteUser']) -> 'User':
+    async def fetch_user(self, user: str | 'User' | 'IncompleteUser') -> 'User':
         """A coroutine that fetches a user from the API.
         
         :param user: A username or object that inherits from `ext.api.User`
@@ -40,11 +39,9 @@ class APIConnection:
         
         return User(self, **data)
     
-    async def fetch_project(self, project: Union[int, str, 'Project', 'IncompleteProject']) -> 'Project':
+    async def fetch_project(self, project: int | str | 'Project') -> 'Project':
         """A coroutine that fetches a project from the API.
         
-        :param owner_username: The username of the owner of the project
-        :type owner_username: str
         :param project: The id of the project or a object that inherits from `ext.api.Project`
 
         :raises NotFoundError: If the data couldn't be accessed by the scratch API
@@ -71,7 +68,7 @@ class APIConnection:
         
         return Project(self, **data)
         
-    async def fetch_studio(self, studio: Union[str, int, 'Studio']) -> 'Studio':
+    async def fetch_studio(self, studio: str | int | 'Studio') -> 'Studio':
         """A coroutine that fetches a studio from the API.
         
         :param studio: The studio id or `ext.api.Studio` object.
@@ -102,20 +99,36 @@ class APIConnection:
 
 @dataclass
 class User:
+    """A dataclass that stores information on users
+    """
+
     connection: APIConnection
+    """the connection used to create the user"""
     id: int
+    """the user's id"""
     username: str
+    """the user's username"""
     
-    scratchteam: int = None
+    scratchteam: bool = None
+    """if the user is a member of the scratchteam"""
 
     history: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
+
     joined: datetime = None
+    """the join date of the user"""
         
     profile: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
+
     status: str = None
+    """the user's profile status"""
     bio: str = None
+    """the user's profile bio"""
     country: str = None
+    """the user's country"""
     image: str = None
+    """the user's image url"""
 
     def __post_init__(self, history, profile):
         if history:
@@ -129,7 +142,7 @@ class User:
                 self.bio = profile['bio']
                 self.country = profile['country']
     
-    async def fetch_favorite_projects(self, limit: int = 20, offset: int = 0) -> List[Project]:
+    async def fetch_favorite_projects(self, limit: int = 20, offset: int = 0) -> list[Project]:
         """Fetches the user's favorite projects.
         
         :param limit: The maximum number of return values,
@@ -139,7 +152,7 @@ class User:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.Project`]
+        :rtype: list[:class:`ext.api.Project`]
         """
 
         PATH = f'https://api.scratch.mit.edu/users/{self.username}/favorites?limit={limit}&offset={offset}'
@@ -148,7 +161,7 @@ class User:
 
         return [Project(connection=self.connection, **project) for project in data]
 
-    async def fetch_projects(self, limit: int = 20, offset: int = 0) -> List[Project]:
+    async def fetch_projects(self, limit: int = 20, offset: int = 0) -> list[Project]:
         """Fetches the user's projects.
         
         :param limit: The maximum number of return values,
@@ -158,7 +171,7 @@ class User:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.Project`]
+        :rtype: list[:class:`ext.api.Project`]
         """
 
         PATH = f'https://api.scratch.mit.edu/users/{self.username}/projects?limit={limit}&offset={offset}'
@@ -167,7 +180,7 @@ class User:
 
         return [Project(connection=self.connection, **project) for project in data]
 
-    async def fetch_followers(self, limit: int = 20, offset: int = 0) -> List[User]:
+    async def fetch_followers(self, limit: int = 20, offset: int = 0) -> list[User]:
         """Fetches the user's followers.
         
         :param limit: The maximum number of return values,
@@ -177,7 +190,7 @@ class User:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.User`]
+        :rtype: list[:class:`ext.api.User`]
         """
 
         PATH = f'https://api.scratch.mit.edu/users/{self.username}/followers?limit={limit}&offset={offset}'
@@ -186,7 +199,7 @@ class User:
 
         return [User(connection=self.connection, **user) for user in data]
 
-    async def fetch_following(self, limit: int = 20, offset: int = 0) -> List[User]:
+    async def fetch_following(self, limit: int = 20, offset: int = 0) -> list[User]:
         """Fetches who the user is following.
         
         :param limit: The maximum number of return values,
@@ -196,7 +209,7 @@ class User:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.User`]
+        :rtype: list[:class:`ext.api.User`]
         """
 
         PATH = f'https://api.scratch.mit.edu/users/{self.username}/following?limit={limit}&offset={offset}'
@@ -218,40 +231,71 @@ class User:
 
 @dataclass
 class IncompleteUser(User):
+    """A dataclass that stores information on users. Contains less information than a normal User object.
+    """
+
     image: str = None
+    """the url of the user's image"""
 
 @dataclass
 class Project:
+    """A dataclass that stores information on projects.
+    """
+
     connection: APIConnection
+    """the connection used to create the project"""
     id: int
+    """the project's id"""
     title: str
+    """the project's title"""
 
     description: str = None
+    """the project's description"""
     instructions: str = None
+    """the project's instructions"""
     visibility: str = None
+    """the project's visibility"""
     public: bool = None
+    """if the project is public"""
     comments_allowed: bool = None
+    """if the project allows comments"""
     is_published: bool = None
+    """if the project is published"""
     image: str = None
+    """the project's image url"""
 
     author: IncompleteUser | InitVar[dict] = None
+    """the project's author"""
 
     history: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
     created: datetime = None
+    """the project's creation date"""
     modified: datetime = None
+    """the project's modification date"""
     shared: datetime = None
+    """the project's share date"""
 
     stats: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
     views: int = None
+    """the project's view count"""
     loves: int = None
+    """the project's love count"""
     favorites: int = None
+    """the project's favorite count"""
     remixes: int = None
+    """the project's remix count"""
 
     remix: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
     parent_id: int = None
+    """if the project is a remix, the project's parent project id"""
     root_id: int = None
+    """if the project is a remix of a remix, the project's root project id"""
 
     images: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
 
     def __post_init__(self, author, history, stats, remix, images):
         if author:
@@ -272,7 +316,7 @@ class Project:
             self.parent_id = remix['parent']
             self.root_id = remix['root']
     
-    async def fetch_comments(self, limit: int = 20, offset: int = 0) -> List[Comment]:
+    async def fetch_comments(self, limit: int = 20, offset: int = 0) -> list[Comment]:
         """Fetches the project's comments.
         
         :param limit: The maximum number of return values,
@@ -282,7 +326,7 @@ class Project:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.Comment`]
+        :rtype: list[:class:`ext.api.Comment`]
         """
 
         comment_path = f'https://api.scratch.mit.edu/users/{self.author.username}/projects/{self.id}/comments'
@@ -292,7 +336,7 @@ class Project:
 
         return [Comment(connection=self.connection, type=CommentType.Project, api_path=comment_path, **comment) for comment in data]
 
-    async def fetch_project_json_object(self) -> ProjectJSON:
+    async def fetch_project_json(self) -> ProjectJSON:
         """Fetches the project's json from the api.
 
         :rtype: ProjectJSON
@@ -306,50 +350,89 @@ class Project:
 
 @dataclass
 class IncompleteProject(Project):
+    """A dataclass that stores information on projects. Contains less information than a normal Project object.
+    """
+
     pass
 
 @dataclass
 class StudioProject(IncompleteProject):
+    """A dataclass that stores information on projects. Contains some studio information.
+    """
+
     actor_id: int = None
+    """the user id of the user who added the project to the studio"""
 
 @dataclass
 class ProjectJSON(dict):
+    """A dataclass that stores project JSON.
+    """
 
     def __init__(self, *args, **kwargs):
         super(ProjectJSON, self).__init__(*args, **kwargs)
 
     def get_block_count(self) -> int:
+        """A method that gets the block count of the project.
+        :rtype: int
+        """
+
         return sum([len(sprite['blocks']) for sprite in self['targets']])
 
     def get_sprite_count(self) -> int:
+        """A method that gets the sprite count of the project.
+        :rtype: int
+        """
         return len(self['targets']) - 1 # Remove stage from sprites
 
     def get_json(self, *args, **kwargs) -> str:
+        """A wrapper for json.dumps. Uses the arguments and keword arguments for json.dumps to get the project json"""
+
         return json.dumps(self, *args, **kwargs)
 
 @dataclass
 class Studio:
+    """A dataclass that stores information on studios.
+    """
+
     connection: APIConnection
+    """the connection used to create the studio"""
     id: int
+    """the studio's id"""
     title: str
+    """the studio's title"""
 
     host: int = None
+    """the studio's host's id"""
     description: str = None
+    """the studio's description"""
     visibility: str = None
+    """the studio's visibility"""
     public: bool = None
+    """if the studio is public"""
     open_to_all: bool = None
+    """if the studio is open for anyone to add projects to"""
     comments_allowed: bool = None
+    """if the studio's comment section is open"""
     image: str = None
+    """the studio's image url"""
 
     history: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
     created: datetime = None
+    """the studio's creation date"""
     modified: datetime = None
+    """the studio's modification date"""
 
     stats: InitVar[dict] = None
+    """an internal variable deleted on object creation"""
     comments: int = None
+    """the studio's comment count"""
     followers: int = None
+    """the studio's follower count"""
     managers: int = None
+    """the studio's manager count"""
     projects: int = None
+    """the studio's project count"""
 
     def __post_init__(self, history, stats):
         if history:
@@ -362,7 +445,7 @@ class Studio:
             self.managers = stats['managers']
             self.projects = stats['projects']
     
-    async def fetch_projects(self, limit: int = 24, offset: int = 0) -> List[StudioProject]:
+    async def fetch_projects(self, limit: int = 24, offset: int = 0) -> list[StudioProject]:
         """Fetches the studio's projects.
         
         :param limit: The maximum number of return values, optional
@@ -372,7 +455,7 @@ class Studio:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.Project`]
+        :rtype: list[:class:`ext.api.Project`]
         """
 
         PATH = f'https://api.scratch.mit.edu/studios/{self.id}/projects/?limit={limit}&offset={offset}'
@@ -396,7 +479,7 @@ class Studio:
         
         return project
 
-    async def fetch_comments(self, limit: int = 20, offset: int = 0) -> List[Comment]:
+    async def fetch_comments(self, limit: int = 20, offset: int = 0) -> list[Comment]:
         """Fetches the studio's comments.
         
         :param limit: The maximum number of return values,
@@ -406,7 +489,7 @@ class Studio:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.Comment`]
+        :rtype: list[:class:`ext.api.Comment`]
         """
 
         comment_path = f'https://api.scratch.mit.edu/studios/{self.id}/comments'
@@ -416,7 +499,7 @@ class Studio:
 
         return [Comment(connection=self.connection, type=CommentType.Studio, api_path=comment_path, **comment) for comment in data]
 
-    async def fetch_managers(self, limit: int = 40, offset: int = 0) -> List[User]:
+    async def fetch_managers(self, limit: int = 40, offset: int = 0) -> list[User]:
         """Fetches the studio's managers from the api.
         
         :param limit: The maximum number of return values,
@@ -426,7 +509,7 @@ class Studio:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.StudioUser`]
+        :rtype: list[:class:`ext.api.StudioUser`]
         """
 
         PATH = f'https://api.scratch.mit.edu/studios/{self.id}/managers/?limit={limit}&offset={offset}'
@@ -435,7 +518,7 @@ class Studio:
 
         return [User(connection=self.connection, **user) for user in data]
 
-    async def fetch_curators(self, limit: int = 40, offset: int = 0) -> List[User]:
+    async def fetch_curators(self, limit: int = 40, offset: int = 0) -> list[User]:
         """Fetches the studio's curators.
         
         :param limit: The maximum number of return values,
@@ -445,7 +528,7 @@ class Studio:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.StudioUser`]
+        :rtype: list[:class:`ext.api.StudioUser`]
         """
 
         PATH = f'https://api.scratch.mit.edu/studios/{self.id}/curators/?limit={limit}&offset={offset}'
@@ -455,32 +538,52 @@ class Studio:
         return [User(connection=self.connection, **user) for user in data]
 
 class CommentType(Enum):
+    """A enum that stores comment type.
+    """
+
     Project = 0
     Studio = 1
 
 @dataclass
 class Comment:
+    """A dataclass that stores information on comments.
+    """
+
     connection: APIConnection
+    """the connection used to create the comment"""
     type: CommentType
+    """the comment's type"""
     api_path: str
+    """the path used for internal api calls """
 
     id: int
+    """the comment's id"""
     
     parent_id: int = None
+    """if the comment is a reply, its parent comment's id"""
     commentee_id: int = None
+    """the comment's sender's id"""
     content: str = None
+    """the comments content"""
 
     datetime_created: InitVar[str] = None
+    """an internal variable deleted on object creation"""
     created: datetime = None
+    """the comment's creation date"""
 
     datetime_modified: InitVar[str] = None
+    """an internal variable deleted on object creation"""
     modified: datetime = None
+    """the comment's modification date"""
 
     visibility: str = None
+    """the comment's visibility"""
 
-    author: InitVar[dict] = None
+    author: IncompleteUser | InitVar[dict] = None
+    """the comment's author"""
 
     reply_count: int = None
+    """the comment's number of replies"""
 
     def __post_init__(self, datetime_created, datetime_modified, author):
         if datetime_created:
@@ -492,7 +595,7 @@ class Comment:
         if author:
             self.author = IncompleteUser(self.connection, **author)
     
-    async def fetch_replies(self, limit: int = 20, offset: int = 0) -> List[Comment]:
+    async def fetch_replies(self, limit: int = 20, offset: int = 0) -> list[Comment]:
         """Fetches the comment's replies.
         
         :param limit: The maximum number of return values,
@@ -502,7 +605,7 @@ class Comment:
             default 0
         :type offset: int, optional
 
-        :rtype: List[:class:`ext.api.Reply`]
+        :rtype: list[:class:`ext.api.Comment`]
         """
 
         data = await self.connection.client.http_session.get(f'{self.api_path}/{self.id}/replies?limit={limit}&offset={offset}')
